Method: RubyXL::Worksheet#before_write_xml

Defined in:
lib/rubyXL/objects/worksheet.rb

#before_write_xmlObject

This method may need to be moved higher in the hierarchy



687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
# File 'lib/rubyXL/objects/worksheet.rb', line 687

def before_write_xml # This method may need to be moved higher in the hierarchy
  first_nonempty_row = nil
  last_nonempty_row = 0
  first_nonempty_column = nil
  last_nonempty_column = 0

  if sheet_data then
    sheet_data.rows.each_with_index { |row, row_index|
      next if row.nil? || row.cells.empty?

      first_nonempty_cell = nil
      last_nonempty_cell = 0

      row.cells.each_with_index { |cell, col_index|
        next if cell.nil?
        cell.r = RubyXL::Reference.new(row_index, col_index)

        first_nonempty_cell ||= col_index
        last_nonempty_cell = col_index
      }

      if first_nonempty_cell then # If there's nothing in this row, then +first_nonempty_cell+ will be +nil+.
        last_nonempty_row = row_index
        first_nonempty_row ||= row_index

        first_nonempty_column ||= first_nonempty_cell
        last_nonempty_column = last_nonempty_cell if last_nonempty_cell > last_nonempty_column
      end

      row.r = row_index + 1
      row.spans = "#{first_nonempty_cell + 1}:#{last_nonempty_cell + 1}" unless first_nonempty_cell.nil?
      row.custom_format = (row.style_index.to_i != 0)
    }

    if first_nonempty_row then
      self.dimension ||= RubyXL::WorksheetDimensions.new
      self.dimension.ref = RubyXL::Reference.new(first_nonempty_row, last_nonempty_row,
                                                 first_nonempty_column, last_nonempty_column)
    end

  end

  true
end