Module: RubyXL::CellConvenienceMethods
- Included in:
- Cell
- Defined in:
- lib/rubyXL/convenience_methods.rb
Instance Method Summary collapse
- #change_border(direction, weight) ⇒ Object
- #change_contents(data, formula_expression = nil) ⇒ Object
-
#change_fill(rgb = 'ffffff') ⇒ Object
Changes fill color of cell.
-
#change_font_bold(bolded = false) ⇒ Object
Changes font bold settings of cell.
-
#change_font_color(font_color = '000000') ⇒ Object
Changes font color of cell.
-
#change_font_italics(italicized = false) ⇒ Object
Changes font italics settings of cell.
-
#change_font_name(new_font_name = 'Verdana') ⇒ Object
Changes font name of cell.
-
#change_font_size(font_size = 10) ⇒ Object
Changes font size of cell.
- #change_font_strikethrough(struckthrough = false) ⇒ Object
-
#change_font_underline(underlined = false) ⇒ Object
Changes font underline settings of cell.
- #change_horizontal_alignment(alignment = 'center') ⇒ Object
- #change_text_wrap(wrap = false) ⇒ Object
- #change_vertical_alignment(alignment = 'center') ⇒ Object
- #fill_color ⇒ Object
- #font_color ⇒ Object
- #font_name ⇒ Object
- #font_size ⇒ Object
-
#font_switch(change_type, arg) ⇒ Object
Performs correct modification based on what type of change_type is specified.
- #get_border(direction) ⇒ Object
- #horizontal_alignment ⇒ Object
- #is_bolded ⇒ Object
- #is_italicized ⇒ Object
- #is_struckthrough ⇒ Object
- #is_underlined ⇒ Object
- #set_number_format(format_code) ⇒ Object
- #text_wrap ⇒ Object
- #vertical_alignment ⇒ Object
Instance Method Details
#change_border(direction, weight) ⇒ Object
676 677 678 679 |
# File 'lib/rubyXL/convenience_methods.rb', line 676 def change_border(direction, weight) validate_worksheet self.style_index = workbook.modify_border(self.style_index, direction, weight) end |
#change_contents(data, formula_expression = nil) ⇒ Object
638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 |
# File 'lib/rubyXL/convenience_methods.rb', line 638 def change_contents(data, formula_expression = nil) validate_worksheet if formula_expression then self.datatype = nil self.formula = RubyXL::Formula.new(:expression => formula_expression) else self.datatype = case data when Date, Numeric then nil else RubyXL::DataType::RAW_STRING end end data = workbook.date_to_num(data) if data.is_a?(Date) self.raw_value = data end |
#change_fill(rgb = 'ffffff') ⇒ Object
Changes fill color of cell
750 751 752 753 754 |
# File 'lib/rubyXL/convenience_methods.rb', line 750 def change_fill(rgb = 'ffffff') validate_worksheet Color.validate_color(rgb) self.style_index = workbook.modify_fill(self.style_index, rgb) end |
#change_font_bold(bolded = false) ⇒ Object
Changes font bold settings of cell
795 796 797 798 799 800 801 |
# File 'lib/rubyXL/convenience_methods.rb', line 795 def change_font_bold(bolded = false) validate_worksheet font = get_cell_font.dup font.set_bold(bolded) update_font_references(font) end |
#change_font_color(font_color = '000000') ⇒ Object
Changes font color of cell
776 777 778 779 780 781 782 783 |
# File 'lib/rubyXL/convenience_methods.rb', line 776 def change_font_color(font_color = '000000') validate_worksheet Color.validate_color(font_color) font = get_cell_font.dup font.set_rgb_color(font_color) update_font_references(font) end |
#change_font_italics(italicized = false) ⇒ Object
Changes font italics settings of cell
786 787 788 789 790 791 792 |
# File 'lib/rubyXL/convenience_methods.rb', line 786 def change_font_italics(italicized = false) validate_worksheet font = get_cell_font.dup font.set_italic(italicized) update_font_references(font) end |
#change_font_name(new_font_name = 'Verdana') ⇒ Object
Changes font name of cell
757 758 759 760 761 762 763 |
# File 'lib/rubyXL/convenience_methods.rb', line 757 def change_font_name(new_font_name = 'Verdana') validate_worksheet font = get_cell_font.dup font.set_name(new_font_name) update_font_references(font) end |
#change_font_size(font_size = 10) ⇒ Object
Changes font size of cell
766 767 768 769 770 771 772 773 |
# File 'lib/rubyXL/convenience_methods.rb', line 766 def change_font_size(font_size = 10) validate_worksheet raise 'Argument must be a number' unless font_size.is_a?(Integer) || font_size.is_a?(Float) font = get_cell_font.dup font.set_size(font_size) update_font_references(font) end |
#change_font_strikethrough(struckthrough = false) ⇒ Object
812 813 814 815 816 817 818 |
# File 'lib/rubyXL/convenience_methods.rb', line 812 def change_font_strikethrough(struckthrough = false) validate_worksheet font = get_cell_font.dup font.set_strikethrough(struckthrough) update_font_references(font) end |
#change_font_underline(underlined = false) ⇒ Object
Changes font underline settings of cell
804 805 806 807 808 809 810 |
# File 'lib/rubyXL/convenience_methods.rb', line 804 def change_font_underline(underlined = false) validate_worksheet font = get_cell_font.dup font.set_underline(underlined) update_font_references(font) end |
#change_horizontal_alignment(alignment = 'center') ⇒ Object
661 662 663 664 |
# File 'lib/rubyXL/convenience_methods.rb', line 661 def change_horizontal_alignment(alignment = 'center') validate_worksheet self.style_index = workbook.modify_alignment(self.style_index) { |a| a.horizontal = alignment } end |
#change_text_wrap(wrap = false) ⇒ Object
671 672 673 674 |
# File 'lib/rubyXL/convenience_methods.rb', line 671 def change_text_wrap(wrap = false) validate_worksheet self.style_index = workbook.modify_alignment(self.style_index) { |a| a.wrap_text = wrap } end |
#change_vertical_alignment(alignment = 'center') ⇒ Object
666 667 668 669 |
# File 'lib/rubyXL/convenience_methods.rb', line 666 def change_vertical_alignment(alignment = 'center') validate_worksheet self.style_index = workbook.modify_alignment(self.style_index) { |a| a.vertical = alignment } end |
#fill_color ⇒ Object
716 717 718 719 |
# File 'lib/rubyXL/convenience_methods.rb', line 716 def fill_color() validate_worksheet return workbook.get_fill_color(get_cell_xf) end |
#font_color ⇒ Object
711 712 713 714 |
# File 'lib/rubyXL/convenience_methods.rb', line 711 def font_color() validate_worksheet get_cell_font.get_rgb_color || '000000' end |
#font_name ⇒ Object
701 702 703 704 |
# File 'lib/rubyXL/convenience_methods.rb', line 701 def font_name() validate_worksheet get_cell_font.get_name end |
#font_size ⇒ Object
706 707 708 709 |
# File 'lib/rubyXL/convenience_methods.rb', line 706 def font_size() validate_worksheet get_cell_font.get_size end |
#font_switch(change_type, arg) ⇒ Object
Performs correct modification based on what type of change_type is specified
828 829 830 831 832 833 834 835 836 837 838 839 |
# File 'lib/rubyXL/convenience_methods.rb', line 828 def font_switch(change_type, arg) case change_type when Worksheet::NAME then change_font_name(arg) when Worksheet::SIZE then change_font_size(arg) when Worksheet::COLOR then change_font_color(arg) when Worksheet::ITALICS then change_font_italics(arg) when Worksheet::BOLD then change_font_bold(arg) when Worksheet::UNDERLINE then change_font_underline(arg) when Worksheet::STRIKETHROUGH then change_font_strikethrough(arg) else raise 'Invalid change_type' end end |
#get_border(direction) ⇒ Object
656 657 658 659 |
# File 'lib/rubyXL/convenience_methods.rb', line 656 def get_border(direction) validate_worksheet get_cell_border.get_edge_style(direction) end |
#horizontal_alignment ⇒ Object
721 722 723 724 725 726 |
# File 'lib/rubyXL/convenience_methods.rb', line 721 def horizontal_alignment() validate_worksheet xf_obj = get_cell_xf return nil if xf_obj.alignment.nil? xf_obj.alignment.horizontal end |
#is_bolded ⇒ Object
686 687 688 689 |
# File 'lib/rubyXL/convenience_methods.rb', line 686 def is_bolded() validate_worksheet get_cell_font.is_bold end |
#is_italicized ⇒ Object
681 682 683 684 |
# File 'lib/rubyXL/convenience_methods.rb', line 681 def is_italicized() validate_worksheet get_cell_font.is_italic end |
#is_struckthrough ⇒ Object
696 697 698 699 |
# File 'lib/rubyXL/convenience_methods.rb', line 696 def is_struckthrough() validate_worksheet get_cell_font.is_strikethrough end |
#is_underlined ⇒ Object
691 692 693 694 |
# File 'lib/rubyXL/convenience_methods.rb', line 691 def is_underlined() validate_worksheet get_cell_font.is_underlined end |
#set_number_format(format_code) ⇒ Object
742 743 744 745 746 747 |
# File 'lib/rubyXL/convenience_methods.rb', line 742 def set_number_format(format_code) new_xf = get_cell_xf.dup new_xf.num_fmt_id = workbook.stylesheet.register_number_format(format_code) new_xf.apply_number_format = true self.style_index = workbook.register_new_xf(new_xf) end |
#text_wrap ⇒ Object
735 736 737 738 739 740 |
# File 'lib/rubyXL/convenience_methods.rb', line 735 def text_wrap() validate_worksheet xf_obj = get_cell_xf return nil if xf_obj.alignment.nil? xf_obj.alignment.wrap_text end |
#vertical_alignment ⇒ Object
728 729 730 731 732 733 |
# File 'lib/rubyXL/convenience_methods.rb', line 728 def vertical_alignment() validate_worksheet xf_obj = get_cell_xf return nil if xf_obj.alignment.nil? xf_obj.alignment.vertical end |