Method: RubyXL::OOXMLObjectInstanceMethods#index_in_collection
- Defined in:
- lib/rubyXL/objects/ooxml_object.rb
#index_in_collection ⇒ Object
Prototype method. For sparse collections (Rows, Cells, etc.) must return index at which this object is expected to reside in the collection. If nil is returned, then object is simply added to the end of the collection.
347 348 349 |
# File 'lib/rubyXL/objects/ooxml_object.rb', line 347 def index_in_collection nil end |