Class: RubyXL::Worksheet
- Inherits:
-
PrivateClass
- Object
- PrivateClass
- RubyXL::Worksheet
- Defined in:
- lib/worksheet.rb
Instance Attribute Summary collapse
-
#cols ⇒ Object
Returns the value of attribute cols.
-
#extLst ⇒ Object
Returns the value of attribute extLst.
-
#legacy_drawing ⇒ Object
Returns the value of attribute legacy_drawing.
-
#merged_cells ⇒ Object
Returns the value of attribute merged_cells.
-
#pane ⇒ Object
Returns the value of attribute pane.
-
#row_styles ⇒ Object
Returns the value of attribute row_styles.
-
#sheet_data ⇒ Object
Returns the value of attribute sheet_data.
-
#sheet_name ⇒ Object
Returns the value of attribute sheet_name.
-
#sheet_view ⇒ Object
Returns the value of attribute sheet_view.
-
#validations ⇒ Object
Returns the value of attribute validations.
-
#workbook ⇒ Object
Returns the value of attribute workbook.
Instance Method Summary collapse
-
#[](row = 0) ⇒ Object
allows for easier access to sheet_data.
- #add_cell(row = 0, column = 0, data = '', formula = nil, overwrite = true) ⇒ Object
- #add_cell_obj(cell, overwrite = true) ⇒ Object
- #change_column_bold(col = 0, bolded = false) ⇒ Object
- #change_column_border_bottom(col = 0, weight = 'thin') ⇒ Object
- #change_column_border_diagonal(col = 0, weight = 'thin') ⇒ Object
- #change_column_border_left(col = 0, weight = 'thin') ⇒ Object
- #change_column_border_right(col = 0, weight = 'thin') ⇒ Object
- #change_column_border_top(col = 0, weight = 'thin') ⇒ Object
- #change_column_fill(col = 0, color_index = 'ffffff') ⇒ Object
- #change_column_font_color(col = 0, font_color = '000000') ⇒ Object
- #change_column_font_name(col = 0, font_name = 'Verdana') ⇒ Object
- #change_column_font_size(col = 0, font_size = 10) ⇒ Object
- #change_column_horizontal_alignment(col = 0, alignment = 'center') ⇒ Object
- #change_column_italics(col = 0, italicized = false) ⇒ Object
- #change_column_strikethrough(col = 0, struckthrough = false) ⇒ Object
- #change_column_underline(col = 0, underlined = false) ⇒ Object
- #change_column_vertical_alignment(col = 0, alignment = 'center') ⇒ Object
- #change_column_width(col = 0, width = 13) ⇒ Object
- #change_row_bold(row = 0, bolded = false) ⇒ Object
- #change_row_border_bottom(row = 0, weight = 'thin') ⇒ Object
- #change_row_border_diagonal(row = 0, weight = 'thin') ⇒ Object
- #change_row_border_left(row = 0, weight = 'thin') ⇒ Object
- #change_row_border_right(row = 0, weight = 'thin') ⇒ Object
- #change_row_border_top(row = 0, weight = 'thin') ⇒ Object
-
#change_row_fill(row = 0, rgb = 'ffffff') ⇒ Object
changes color of fill in (zer0 indexed) row.
- #change_row_font_color(row = 0, font_color = '000000') ⇒ Object
- #change_row_font_name(row = 0, font_name = 'Verdana') ⇒ Object
- #change_row_font_size(row = 0, font_size = 10) ⇒ Object
- #change_row_height(row = 0, height = 10) ⇒ Object
- #change_row_horizontal_alignment(row = 0, alignment = 'center') ⇒ Object
- #change_row_italics(row = 0, italicized = false) ⇒ Object
- #change_row_strikethrough(row = 0, struckthrough = false) ⇒ Object
- #change_row_underline(row = 0, underlined = false) ⇒ Object
- #change_row_vertical_alignment(row = 0, alignment = 'center') ⇒ Object
- #get_column_border_bottom(col = 0) ⇒ Object
- #get_column_border_diagonal(col = 0) ⇒ Object
- #get_column_border_left(col = 0) ⇒ Object
- #get_column_border_right(col = 0) ⇒ Object
- #get_column_border_top(col = 0) ⇒ Object
- #get_column_fill(col = 0) ⇒ Object
- #get_column_font_color(col = 0) ⇒ Object
- #get_column_font_name(col = 0) ⇒ Object
- #get_column_font_size(col = 0) ⇒ Object
- #get_column_horizontal_alignment(col = 0) ⇒ Object
- #get_column_vertical_alignment(col = 0) ⇒ Object
- #get_column_width(col = 0) ⇒ Object
- #get_row_border_bottom(row = 0) ⇒ Object
- #get_row_border_diagonal(row = 0) ⇒ Object
- #get_row_border_left(row = 0) ⇒ Object
- #get_row_border_right(row = 0) ⇒ Object
- #get_row_border_top(row = 0) ⇒ Object
- #get_row_fill(row = 0) ⇒ Object
- #get_row_font_color(row = 0) ⇒ Object
- #get_row_font_name(row = 0) ⇒ Object
- #get_row_font_size(row = 0) ⇒ Object
- #get_row_height(row = 0) ⇒ Object
- #get_row_horizontal_alignment(row = 0) ⇒ Object
- #get_row_vertical_alignment(row = 0) ⇒ Object
- #get_table(headers = []) ⇒ Object
-
#initialize(workbook, sheet_name = 'Sheet1', sheet_data = [[nil]], cols = [], merged_cells = []) ⇒ Worksheet
constructor
A new instance of Worksheet.
-
#insert_column(col_index) ⇒ Object
inserts column at col_index, pushes everything right, takes styles from column to left USE OF THIS METHOD will break formulas which reference cells which are being “pushed down”.
-
#insert_row(row_index) ⇒ Object
inserts row at row_index, pushes down, copies style from below (row previously at that index) USE OF THIS METHOD will break formulas which reference cells which are being “pushed down”.
- #is_column_bolded(col = 0) ⇒ Object
- #is_column_italicized(col = 0) ⇒ Object
- #is_column_struckthrough(col = 0) ⇒ Object
- #is_column_underlined(col = 0) ⇒ Object
- #is_row_bolded(row = 0) ⇒ Object
- #is_row_italicized(row = 0) ⇒ Object
- #is_row_struckthrough(row = 0) ⇒ Object
- #is_row_underlined(row = 0) ⇒ Object
-
#merge_cells(row1 = 0, col1 = 0, row2 = 0, col2 = 0) ⇒ Object
merges cells within a rectangular range.
Constructor Details
#initialize(workbook, sheet_name = 'Sheet1', sheet_data = [[nil]], cols = [], merged_cells = []) ⇒ Worksheet
Returns a new instance of Worksheet.
7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 |
# File 'lib/worksheet.rb', line 7 def initialize(workbook, sheet_name='Sheet1',sheet_data=[[nil]],cols=[], merged_cells=[]) @workbook = workbook @sheet_name = sheet_name @sheet_data = sheet_data @cols = cols @merged_cells = merged_cells @row_styles={} @sheet_view = { :attributes => { :workbookViewId => 0, :zoomScale => 100, :tabSelected => 1, :view=>'normalLayout', :zoomScaleNormal => 100 } } @extLst = nil @legacy_drawing=nil end |
Instance Attribute Details
#cols ⇒ Object
Returns the value of attribute cols.
4 5 6 |
# File 'lib/worksheet.rb', line 4 def cols @cols end |
#extLst ⇒ Object
Returns the value of attribute extLst.
4 5 6 |
# File 'lib/worksheet.rb', line 4 def extLst @extLst end |
#legacy_drawing ⇒ Object
Returns the value of attribute legacy_drawing.
4 5 6 |
# File 'lib/worksheet.rb', line 4 def legacy_drawing @legacy_drawing end |
#merged_cells ⇒ Object
Returns the value of attribute merged_cells.
4 5 6 |
# File 'lib/worksheet.rb', line 4 def merged_cells @merged_cells end |
#pane ⇒ Object
Returns the value of attribute pane.
4 5 6 |
# File 'lib/worksheet.rb', line 4 def pane @pane end |
#row_styles ⇒ Object
Returns the value of attribute row_styles.
4 5 6 |
# File 'lib/worksheet.rb', line 4 def row_styles @row_styles end |
#sheet_data ⇒ Object
Returns the value of attribute sheet_data.
4 5 6 |
# File 'lib/worksheet.rb', line 4 def sheet_data @sheet_data end |
#sheet_name ⇒ Object
Returns the value of attribute sheet_name.
4 5 6 |
# File 'lib/worksheet.rb', line 4 def sheet_name @sheet_name end |
#sheet_view ⇒ Object
Returns the value of attribute sheet_view.
4 5 6 |
# File 'lib/worksheet.rb', line 4 def sheet_view @sheet_view end |
#validations ⇒ Object
Returns the value of attribute validations.
4 5 6 |
# File 'lib/worksheet.rb', line 4 def validations @validations end |
#workbook ⇒ Object
Returns the value of attribute workbook.
4 5 6 |
# File 'lib/worksheet.rb', line 4 def workbook @workbook end |
Instance Method Details
#[](row = 0) ⇒ Object
allows for easier access to sheet_data
25 26 27 |
# File 'lib/worksheet.rb', line 25 def [](row=0) return @sheet_data[row] end |
#add_cell(row = 0, column = 0, data = '', formula = nil, overwrite = true) ⇒ Object
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/worksheet.rb', line 336 def add_cell(row=0, column=0, data='', formula=nil,overwrite=true) validate_workbook validate_nonnegative(row) validate_nonnegative(column) unless @sheet_data.size > row && @sheet_data[row].size > column increase_columns(column) increase_rows(row) end datatype = 'str' unless formula.nil? datatype = '' end if overwrite || @sheet_data[row][column].nil? @sheet_data[row][column] = Cell.new(self,row,column,data,formula,datatype) if (data.is_a?Integer) || (data.is_a?Float) @sheet_data[row][column].datatype = '' end col = @cols[get_cols_index(column)] if @row_styles[(row+1).to_s] != nil @sheet_data[row][column].style_index = @row_styles[(row+1).to_s][:style] elsif col != nil @sheet_data[row][column].style_index = col[:attributes][:style] end end add_cell_style(row,column) return @sheet_data[row][column] end |
#add_cell_obj(cell, overwrite = true) ⇒ Object
370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'lib/worksheet.rb', line 370 def add_cell_obj(cell, overwrite=true) validate_workbook if cell.nil? return cell end row = cell.row column = cell.column validate_nonnegative(row) validate_nonnegative(column) unless @sheet_data.size > row && @sheet_data[row].size > column increase_columns(column) increase_rows(row) end if overwrite || @sheet_data[row][column].nil? @sheet_data[row][column] = cell end add_cell_style(row,column) return @sheet_data[row][column] end |
#change_column_bold(col = 0, bolded = false) ⇒ Object
225 226 227 228 |
# File 'lib/worksheet.rb', line 225 def change_column_bold(col=0,bolded=false) s = change_column_font(col,Worksheet::BOLD,bolded) @workbook.fonts[font_id(s)][:font][:b] = bolded ? {} : nil end |
#change_column_border_bottom(col = 0, weight = 'thin') ⇒ Object
315 316 317 |
# File 'lib/worksheet.rb', line 315 def change_column_border_bottom(col=0,weight='thin') change_column_border(col,:bottom,weight) end |
#change_column_border_diagonal(col = 0, weight = 'thin') ⇒ Object
319 320 321 |
# File 'lib/worksheet.rb', line 319 def change_column_border_diagonal(col=0,weight='thin') change_column_border(col,:diagonal,weight) end |
#change_column_border_left(col = 0, weight = 'thin') ⇒ Object
307 308 309 |
# File 'lib/worksheet.rb', line 307 def change_column_border_left(col=0,weight='thin') change_column_border(col,:left,weight) end |
#change_column_border_right(col = 0, weight = 'thin') ⇒ Object
311 312 313 |
# File 'lib/worksheet.rb', line 311 def change_column_border_right(col=0,weight='thin') change_column_border(col,:right,weight) end |
#change_column_border_top(col = 0, weight = 'thin') ⇒ Object
303 304 305 |
# File 'lib/worksheet.rb', line 303 def change_column_border_top(col=0,weight='thin') change_column_border(col,:top,weight) end |
#change_column_fill(col = 0, color_index = 'ffffff') ⇒ Object
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/worksheet.rb', line 260 def change_column_fill(col=0, color_index='ffffff') validate_workbook validate_nonnegative(col) Color.validate_color(color_index) increase_columns(col) i = get_cols_index(col) if cols[i].nil? style_index = 0 else #just copies any style if there is none which already exists for this col #while it changes style/min/max, width *might* be preserved style_index = Integer(@cols[i][:attributes][:style]) end modify_fill(@workbook,style_index,color_index) change_cols(i,col) @sheet_data.each_with_index do |row,i| c = row[Integer(col)] unless c.nil? c.change_fill(color_index) end end end |
#change_column_font_color(col = 0, font_color = '000000') ⇒ Object
208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/worksheet.rb', line 208 def change_column_font_color(col=0,font_color='000000') Color.validate_color(font_color) s = change_column_font(col,Worksheet::COLOR,font_color) font = @workbook.fonts[font_id(s)][:font] if font[:color].nil? || font[:color][:attributes].nil? font[:color] = { :attributes => { :rgb => nil } } end font[:color][:attributes][:rgb] = font_color.to_s end |
#change_column_font_name(col = 0, font_name = 'Verdana') ⇒ Object
198 199 200 201 |
# File 'lib/worksheet.rb', line 198 def change_column_font_name(col=0,font_name='Verdana') s = change_column_font(col,Worksheet::NAME,font_name) @workbook.fonts[font_id(s)][:font][:name][:attributes][:val] = font_name.to_s end |
#change_column_font_size(col = 0, font_size = 10) ⇒ Object
203 204 205 206 |
# File 'lib/worksheet.rb', line 203 def change_column_font_size(col=0,font_size=10) s = change_column_font(col,Worksheet::SIZE,font_size) @workbook.fonts[font_id(s)][:font][:sz][:attributes][:val] = font_size end |
#change_column_horizontal_alignment(col = 0, alignment = 'center') ⇒ Object
289 290 291 292 293 294 |
# File 'lib/worksheet.rb', line 289 def change_column_horizontal_alignment(col=0,alignment='center') validate_workbook validate_nonnegative(col) validate_horizontal_alignment(alignment) change_column_alignment(col,alignment,true) end |
#change_column_italics(col = 0, italicized = false) ⇒ Object
220 221 222 223 |
# File 'lib/worksheet.rb', line 220 def change_column_italics(col=0,italicized=false) s = change_column_font(col,Worksheet::ITALICS,italicized) @workbook.fonts[font_id(s)][:font][:i] = italicized ? {} : nil end |
#change_column_strikethrough(col = 0, struckthrough = false) ⇒ Object
235 236 237 238 |
# File 'lib/worksheet.rb', line 235 def change_column_strikethrough(col=0,struckthrough=false) s = change_column_font(col,Worksheet::STRIKETHROUGH,struckthrough) @workbook.fonts[font_id(s)][:font][:strike] = struckthrough ? {} : nil end |
#change_column_underline(col = 0, underlined = false) ⇒ Object
230 231 232 233 |
# File 'lib/worksheet.rb', line 230 def change_column_underline(col=0,underlined=false) s = change_column_font(col,Worksheet::UNDERLINE,underlined) @workbook.fonts[font_id(s)][:font][:u] = underlined ? {} : nil end |
#change_column_vertical_alignment(col = 0, alignment = 'center') ⇒ Object
296 297 298 299 300 301 |
# File 'lib/worksheet.rb', line 296 def change_column_vertical_alignment(col=0,alignment='center') validate_workbook validate_nonnegative(col) validate_vertical_alignment(alignment) change_column_alignment(col,alignment,false) end |
#change_column_width(col = 0, width = 13) ⇒ Object
240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/worksheet.rb', line 240 def change_column_width(col=0,width=13) validate_workbook validate_nonnegative(col) increase_columns(col) i = get_cols_index(col) if width.to_i.to_s == width.to_s width = Integer(width) elsif width.to_f.to_s == width.to_s width = Float(width) else raise 'You must enter a number for the width' end change_cols(i,col) @cols.last[:attributes][:width] = width @cols.last[:attributes][:customWidth] = '1' end |
#change_row_bold(row = 0, bolded = false) ⇒ Object
127 128 129 130 |
# File 'lib/worksheet.rb', line 127 def change_row_bold(row=0,bolded=false) change_row_font(row,Worksheet::BOLD,bolded) @workbook.fonts[font_id(@row_styles[(row+1).to_s][:style])][:font][:b] = bolded ? {} : nil end |
#change_row_border_bottom(row = 0, weight = 'thin') ⇒ Object
190 191 192 |
# File 'lib/worksheet.rb', line 190 def change_row_border_bottom(row=0,weight='thin') change_row_border(row, :bottom, weight) end |
#change_row_border_diagonal(row = 0, weight = 'thin') ⇒ Object
194 195 196 |
# File 'lib/worksheet.rb', line 194 def change_row_border_diagonal(row=0,weight='thin') change_row_border(row, :diagonal, weight) end |
#change_row_border_left(row = 0, weight = 'thin') ⇒ Object
182 183 184 |
# File 'lib/worksheet.rb', line 182 def change_row_border_left(row=0,weight='thin') change_row_border(row, :left, weight) end |
#change_row_border_right(row = 0, weight = 'thin') ⇒ Object
186 187 188 |
# File 'lib/worksheet.rb', line 186 def change_row_border_right(row=0,weight='thin') change_row_border(row, :right, weight) end |
#change_row_border_top(row = 0, weight = 'thin') ⇒ Object
178 179 180 |
# File 'lib/worksheet.rb', line 178 def change_row_border_top(row=0,weight='thin') change_row_border(row, :top, weight) end |
#change_row_fill(row = 0, rgb = 'ffffff') ⇒ Object
changes color of fill in (zer0 indexed) row
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/worksheet.rb', line 81 def change_row_fill(row=0,rgb='ffffff') validate_workbook validate_nonnegative(row) increase_rows(row) Color.validate_color(rgb) if @row_styles[(Integer(row)+1).to_s].nil? @row_styles[(Integer(row)+1).to_s] = {} @row_styles[(Integer(row)+1).to_s][:style] = '0' end @row_styles[(Integer(row)+1).to_s][:style] = modify_fill(@workbook,Integer(@row_styles[(Integer(row)+1).to_s][:style]),rgb) @sheet_data[Integer(row)].each do |c| unless c.nil? c.change_fill(rgb) end end end |
#change_row_font_color(row = 0, font_color = '000000') ⇒ Object
110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/worksheet.rb', line 110 def change_row_font_color(row=0,font_color='000000') Color.validate_color(font_color) change_row_font(row,Worksheet::COLOR,font_color) font = @workbook.fonts[font_id(@row_styles[(row+1).to_s][:style])][:font] if font[:color].nil? || font[:color][:attributes].nil? font[:color] = { :attributes => { :rgb => nil } } end font[:color][:attributes][:rgb] = font_color.to_s end |
#change_row_font_name(row = 0, font_name = 'Verdana') ⇒ Object
100 101 102 103 |
# File 'lib/worksheet.rb', line 100 def change_row_font_name(row=0,font_name='Verdana') change_row_font(row,Worksheet::NAME,font_name) @workbook.fonts[font_id(@row_styles[(row+1).to_s][:style])][:font][:name][:attributes][:val] = font_name.to_s end |
#change_row_font_size(row = 0, font_size = 10) ⇒ Object
105 106 107 108 |
# File 'lib/worksheet.rb', line 105 def change_row_font_size(row=0,font_size=10) change_row_font(row,Worksheet::SIZE,font_size) @workbook.fonts[font_id(@row_styles[(row+1).to_s][:style])][:font][:sz][:attributes][:val] = font_size end |
#change_row_height(row = 0, height = 10) ⇒ Object
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/worksheet.rb', line 142 def change_row_height(row=0,height=10) validate_workbook validate_nonnegative(row) increase_rows(row) if height.to_i.to_s == height.to_s height = Integer(height) elsif height.to_f.to_s == height.to_s height = Float(height) else raise 'You must enter a number for the height' end if @row_styles[(row+1).to_s].nil? @row_styles[(row+1).to_s] = {} @row_styles[(row+1).to_s][:style] = '0' end @row_styles[(row+1).to_s][:height] = height @row_styles[(row+1).to_s][:customHeight] = '1' end |
#change_row_horizontal_alignment(row = 0, alignment = 'center') ⇒ Object
164 165 166 167 168 169 |
# File 'lib/worksheet.rb', line 164 def change_row_horizontal_alignment(row=0,alignment='center') validate_workbook validate_nonnegative(row) validate_horizontal_alignment(alignment) change_row_alignment(row,alignment,true) end |
#change_row_italics(row = 0, italicized = false) ⇒ Object
122 123 124 125 |
# File 'lib/worksheet.rb', line 122 def change_row_italics(row=0,italicized=false) change_row_font(row,Worksheet::ITALICS,italicized) @workbook.fonts[font_id(@row_styles[(row+1).to_s][:style])][:font][:i] = italicized ? {} : nil end |
#change_row_strikethrough(row = 0, struckthrough = false) ⇒ Object
137 138 139 140 |
# File 'lib/worksheet.rb', line 137 def change_row_strikethrough(row=0,struckthrough=false) change_row_font(row,Worksheet::STRIKETHROUGH,struckthrough) @workbook.fonts[font_id(@row_styles[(row+1).to_s][:style])][:font][:strike] = struckthrough ? {} : nil end |
#change_row_underline(row = 0, underlined = false) ⇒ Object
132 133 134 135 |
# File 'lib/worksheet.rb', line 132 def change_row_underline(row=0,underlined=false) change_row_font(row,Worksheet::UNDERLINE,underlined) @workbook.fonts[font_id(@row_styles[(row+1).to_s][:style])][:font][:u] = underlined ? {} : nil end |
#change_row_vertical_alignment(row = 0, alignment = 'center') ⇒ Object
171 172 173 174 175 176 |
# File 'lib/worksheet.rb', line 171 def change_row_vertical_alignment(row=0,alignment='center') validate_workbook validate_nonnegative(row) validate_vertical_alignment(alignment) change_row_alignment(row,alignment,false) end |
#get_column_border_bottom(col = 0) ⇒ Object
768 769 770 |
# File 'lib/worksheet.rb', line 768 def get_column_border_bottom(col=0) return get_column_border(col,:bottom) end |
#get_column_border_diagonal(col = 0) ⇒ Object
772 773 774 |
# File 'lib/worksheet.rb', line 772 def get_column_border_diagonal(col=0) return get_column_border(col,:diagonal) end |
#get_column_border_left(col = 0) ⇒ Object
760 761 762 |
# File 'lib/worksheet.rb', line 760 def get_column_border_left(col=0) return get_column_border(col,:left) end |
#get_column_border_right(col = 0) ⇒ Object
764 765 766 |
# File 'lib/worksheet.rb', line 764 def get_column_border_right(col=0) return get_column_border(col,:right) end |
#get_column_border_top(col = 0) ⇒ Object
756 757 758 |
# File 'lib/worksheet.rb', line 756 def get_column_border_top(col=0) return get_column_border(col,:top) end |
#get_column_fill(col = 0) ⇒ Object
731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 |
# File 'lib/worksheet.rb', line 731 def get_column_fill(col=0) validate_workbook validate_nonnegative(col) if @sheet_data[0].size <= col return nil end style_index = get_cols_style_index(col) if style_index == 0 return "ffffff" #default, white end return @workbook.get_fill_color(@workbook.cell_xfs[:xf][style_index][:attributes]) end |
#get_column_font_color(col = 0) ⇒ Object
678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 |
# File 'lib/worksheet.rb', line 678 def get_column_font_color(col=0) validate_workbook validate_nonnegative(col) if @sheet_data[0].size <= col return nil end style_index = get_cols_style_index(col) font = @workbook.fonts[font_id( style_index ).to_s][:font] if font[:color].nil? || font[:color][:attributes].nil? || font[:color][:attributes][:rgb].nil? return '000000' end return font[:color][:attributes][:rgb] end |
#get_column_font_name(col = 0) ⇒ Object
652 653 654 655 656 657 658 659 660 661 662 663 |
# File 'lib/worksheet.rb', line 652 def get_column_font_name(col=0) validate_workbook validate_nonnegative(col) if @sheet_data[0].size <= col return nil end style_index = get_cols_style_index(col) return @workbook.fonts[font_id( style_index ).to_s][:font][:name][:attributes][:val] end |
#get_column_font_size(col = 0) ⇒ Object
665 666 667 668 669 670 671 672 673 674 675 676 |
# File 'lib/worksheet.rb', line 665 def get_column_font_size(col=0) validate_workbook validate_nonnegative(col) if @sheet_data[0].size <= col return nil end style_index = get_cols_style_index(col) return @workbook.fonts[font_id( style_index ).to_s][:font][:sz][:attributes][:val] end |
#get_column_horizontal_alignment(col = 0) ⇒ Object
748 749 750 |
# File 'lib/worksheet.rb', line 748 def get_column_horizontal_alignment(col=0) get_column_alignment(col, :horizontal) end |
#get_column_vertical_alignment(col = 0) ⇒ Object
752 753 754 |
# File 'lib/worksheet.rb', line 752 def get_column_vertical_alignment(col=0) get_column_alignment(col, :vertical) end |
#get_column_width(col = 0) ⇒ Object
714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 |
# File 'lib/worksheet.rb', line 714 def get_column_width(col=0) validate_workbook validate_nonnegative(col) if @sheet_data[0].size <= col return nil end cols_index = get_cols_index(col) if @cols[cols_index].nil? || @cols[cols_index][:attributes].nil? || @cols[cols_index][:attributes][:width].to_s == '' return 10 end return @cols[cols_index][:attributes][:width] end |
#get_row_border_bottom(row = 0) ⇒ Object
644 645 646 |
# File 'lib/worksheet.rb', line 644 def get_row_border_bottom(row=0) return get_row_border(row,:bottom) end |
#get_row_border_diagonal(row = 0) ⇒ Object
648 649 650 |
# File 'lib/worksheet.rb', line 648 def get_row_border_diagonal(row=0) return get_row_border(row,:diagonal) end |
#get_row_border_left(row = 0) ⇒ Object
636 637 638 |
# File 'lib/worksheet.rb', line 636 def get_row_border_left(row=0) return get_row_border(row,:left) end |
#get_row_border_right(row = 0) ⇒ Object
640 641 642 |
# File 'lib/worksheet.rb', line 640 def get_row_border_right(row=0) return get_row_border(row,:right) end |
#get_row_border_top(row = 0) ⇒ Object
632 633 634 |
# File 'lib/worksheet.rb', line 632 def get_row_border_top(row=0) return get_row_border(row,:top) end |
#get_row_fill(row = 0) ⇒ Object
518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 |
# File 'lib/worksheet.rb', line 518 def get_row_fill(row=0) validate_workbook validate_nonnegative(row) if @sheet_data.size <= row return nil end if @row_styles[(row+1).to_s].nil? return "ffffff" #default, white end xf = xf_attr_row(row) return @workbook.get_fill_color(xf) end |
#get_row_font_color(row = 0) ⇒ Object
569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 |
# File 'lib/worksheet.rb', line 569 def get_row_font_color(row=0) validate_workbook validate_nonnegative(row) if @sheet_data.size <= row return nil end if @row_styles[(row+1).to_s].nil? return '000000' end xf = xf_attr_row(row) color = @workbook.fonts[xf[:fontId].to_s][:font][:color] if color.nil? || color[:attributes].nil? || color[:attributes][:rgb].nil? return '000000' end return color[:attributes][:rgb] end |
#get_row_font_name(row = 0) ⇒ Object
535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 |
# File 'lib/worksheet.rb', line 535 def get_row_font_name(row=0) validate_workbook validate_nonnegative(row) if @sheet_data.size <= row return nil end if @row_styles[(row+1).to_s].nil? return 'Verdana' end xf = xf_attr_row(row) return @workbook.fonts[xf[:fontId].to_s][:font][:name][:attributes][:val] end |
#get_row_font_size(row = 0) ⇒ Object
552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 |
# File 'lib/worksheet.rb', line 552 def get_row_font_size(row=0) validate_workbook validate_nonnegative(row) if @sheet_data.size <= row return nil end if @row_styles[(row+1).to_s].nil? return '10' end xf = xf_attr_row(row) return @workbook.fonts[xf[:fontId].to_s][:font][:sz][:attributes][:val] end |
#get_row_height(row = 0) ⇒ Object
609 610 611 612 613 614 615 616 617 618 619 620 621 622 |
# File 'lib/worksheet.rb', line 609 def get_row_height(row=0) validate_workbook validate_nonnegative(row) if @sheet_data.size <= row return nil end if @row_styles[(row+1).to_s].nil? return 13 else @row_styles[(row+1).to_s][:height] end end |
#get_row_horizontal_alignment(row = 0) ⇒ Object
624 625 626 |
# File 'lib/worksheet.rb', line 624 def get_row_horizontal_alignment(row=0) return get_row_alignment(row,true) end |
#get_row_vertical_alignment(row = 0) ⇒ Object
628 629 630 |
# File 'lib/worksheet.rb', line 628 def get_row_vertical_alignment(row=0) return get_row_alignment(row,false) end |
#get_table(headers = []) ⇒ Object
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/worksheet.rb', line 29 def get_table(headers=[]) validate_workbook if !headers.is_a?(Array) headers = [headers] end row_num = find_first_row_with_content(headers) if row_num.nil? return nil end table_hash = {} table_hash[:table] = [] headers.each do |header| row_strings = @sheet_data[row_num].map { |cell| cell.nil? ? '' : cell.value.to_s } header_column = row_strings.index(header) table_hash[header.to_sym] = [] original_row = row_num + 1 current_row = original_row cell = @sheet_data[current_row][header_column] # makes array of hashes in table_hash[:table] # as well as hash of arrays in table_hash[header.to_sym] while !cell.nil? && !cell.value.nil? table_hash[header.to_sym] << cell.value table_index = current_row - original_row if table_hash[:table][table_index].nil? table_hash[:table][table_index] = {} end table_hash[:table][table_index][header.to_sym] = cell.value current_row += 1 if @sheet_data[current_row].nil? cell = nil else cell = @sheet_data[current_row][header_column] end end end return table_hash end |
#insert_column(col_index) ⇒ Object
inserts column at col_index, pushes everything right, takes styles from column to left USE OF THIS METHOD will break formulas which reference cells which are being “pushed down”
455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 |
# File 'lib/worksheet.rb', line 455 def insert_column(col_index) validate_workbook validate_nonnegative(col_index) increase_columns(col_index) old_index = col_index > 0 ? col_index-1 : col_index+1 old_col = @cols[get_cols_index(old_index)] if old_index == 1 old_col = nil end #go through each cell in column @sheet_data.each_with_index do |r,i| #insert "column" in each row r.insert(col_index, nil) #copy styles over to each cell old_cell = r[old_index] unless old_cell.nil? #only add cell if style exists, not copying content if old_cell.style_index != 0 if !old_col.nil? && old_cell.style_index.to_s != old_col[:attributes][:style].to_s c = Cell.new(self,i,col_index) c.style_index = old_cell.style_index @sheet_data[i][col_index] = c end end end end #copy over column-level styles new_col = change_cols(get_cols_index(old_index),old_index) @cols[-1] = deep_copy(old_col)#-1 = last new_col = @cols.last if @cols.last.nil? @cols.pop end #shift col styles 'right' @cols.each do |col| if Integer(col[:attributes][:min]) > col_index col[:attributes][:min] = (1 + Integer(col[:attributes][:min])).to_s end if Integer(col[:attributes][:max]) > col_index col[:attributes][:max] = (1 + Integer(col[:attributes][:max])).to_s end end unless new_col.nil? new_col[:attributes][:min] = (1 + Integer(new_col[:attributes][:min])).to_s new_col[:attributes][:max] = (1 + Integer(new_col[:attributes][:max])).to_s end #update column numbers @sheet_data.each do |row| (col_index+1).upto(row.size) do |j| unless row[j].nil? row[j].column += 1 end end end end |
#insert_row(row_index) ⇒ Object
inserts row at row_index, pushes down, copies style from below (row previously at that index) USE OF THIS METHOD will break formulas which reference cells which are being “pushed down”
398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 |
# File 'lib/worksheet.rb', line 398 def insert_row(row_index) validate_workbook validate_nonnegative(row_index) increase_rows(row_index) @sheet_data.insert(row_index,Array.new(@sheet_data[row_index].size)) row_num = row_index+1 #copy cell styles from row above, (or below if first row) @sheet_data[row_index].each_index do |i| if row_index > 0 old_cell = @sheet_data[row_index-1][i] else old_cell = @sheet_data[row_index+1][i] end unless old_cell.nil? #only add cell if style exists, not copying content if @row_styles[(row_num+1).to_s].nil? @row_styles[(row_num+1).to_s] = {:style=>0} end if old_cell.style_index != 0 && old_cell.style_index.to_s != @row_styles[(row_num+1).to_s][:style].to_s c = Cell.new(self,row_index,i) c.style_index = old_cell.style_index @sheet_data[row_index][i] = c end end end #copy row styles from row above, (or below if first row) (@row_styles.size+1).downto(row_num+1) do |i| @row_styles[i.to_s] = @row_styles[(i-1).to_s] end if row_index > 0 @row_styles[row_num.to_s] = @row_styles[(row_num-1).to_s] else @row_styles[row_num.to_s] = nil#@row_styles[(row_num+1).to_s] end #update row value for all rows below (row_index+1).upto(@sheet_data.size-1) do |i| row = @sheet_data[i] row.each do |c| unless c.nil? c.row += 1 end end end return @sheet_data[row_index] end |
#is_column_bolded(col = 0) ⇒ Object
702 703 704 |
# File 'lib/worksheet.rb', line 702 def is_column_bolded(col=0) get_column_bool(col,:b) end |
#is_column_italicized(col = 0) ⇒ Object
698 699 700 |
# File 'lib/worksheet.rb', line 698 def is_column_italicized(col=0) get_column_bool(col,:i) end |
#is_column_struckthrough(col = 0) ⇒ Object
710 711 712 |
# File 'lib/worksheet.rb', line 710 def is_column_struckthrough(col=0) get_column_bool(col,:strike) end |
#is_column_underlined(col = 0) ⇒ Object
706 707 708 |
# File 'lib/worksheet.rb', line 706 def is_column_underlined(col=0) get_column_bool(col,:u) end |
#is_row_bolded(row = 0) ⇒ Object
596 597 598 |
# File 'lib/worksheet.rb', line 596 def is_row_bolded(row=0) return get_row_bool(row,:b) end |
#is_row_italicized(row = 0) ⇒ Object
592 593 594 |
# File 'lib/worksheet.rb', line 592 def is_row_italicized(row=0) return get_row_bool(row,:i) end |
#is_row_struckthrough(row = 0) ⇒ Object
604 605 606 |
# File 'lib/worksheet.rb', line 604 def is_row_struckthrough(row=0) return get_row_bool(row,:strike) end |
#is_row_underlined(row = 0) ⇒ Object
600 601 602 |
# File 'lib/worksheet.rb', line 600 def is_row_underlined(row=0) return get_row_bool(row,:u) end |
#merge_cells(row1 = 0, col1 = 0, row2 = 0, col2 = 0) ⇒ Object
merges cells within a rectangular range
324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/worksheet.rb', line 324 def merge_cells(row1=0,col1=0,row2=0,col2=0) validate_workbook @merged_cells << { :attributes => { :ref => '' } } cell1 = Cell.convert_to_cell(row1,col1) cell2 = Cell.convert_to_cell(row2,col2) @merged_cells.last[:attributes][:ref] = cell1+':'+cell2 end |